import {
  select,
  csv,
  scaleLinear,
  scaleTime,
  extent,
  axisLeft,
  axisBottom,
  line,
  max
} from 'd3';

//redering svg tag from html
const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

//Creating Line graph
const render = data => { 
  //Declaring constants we are using
  const title = 'Test';
  
  const xValue = d => d.date; //display dates on x axis
  const xAxisLabel = 'Date';

  const yValue = d => d.nb_musique; //display salees value on y axis
  const yAxisLabel = 'Nombre de Musique';
  
  const margin = { top: 60, right: 40, bottom: 88, left: 150 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  //container
  
  
  //center g in svg
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);
  
  
  // Create X scale with year values
  const xScale = scaleTime()
  //complete set of values
    .domain(extent(data, xValue))
  //returns the minimum and maximum value in an array from the given array using natural order.
    .range([0, innerWidth]) //output bounds
    .nice(); //round values out
  
  //console.log(xScale.data);
 
  //creating xAxis  
  const xAxis = axisBottom(xScale)
    .tickSize(-innerHeight)
    .tickPadding(15);
  
  
  // Create Y scale with sales values
  const yScale = scaleLinear()
    .domain([0, max(data, yValue )])
    .range([innerHeight, 0])
    .nice();
  
  //creating yAxis  
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(10);
  
  //Appending Y axis label to svg
  const yAxisG = g.append('g').call(yAxis);
  	yAxisG.selectAll('.domain').remove();
  	yAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', -90)
      .attr('x', -innerHeight / 3)
      .attr('fill', 'black')
      .attr('transform', `rotate(-90)`)
      .text(yAxisLabel);
  
  //Appending X axis label to svg
  const xAxisG = g.append('g').call(xAxis)
    	.attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', 70)
      .attr('x', innerWidth / 2)
      .attr('fill', 'black')
      .text(xAxisLabel);
  
  //Creating line graphs between x and y axis
  const lineGenerator = d3.line()
  	.x(d => xScale(xValue(d)))
  	.y(d => yScale(yValue(d))); //coordinates in pixels
  
  //Appending line graph to svg
  g.append('path')
  	.attr('class', 'line_path')
  	.attr('d', lineGenerator(data))
  //Appending title of graph to svg
  g.append('text')
      .attr('class', 'title')
      .attr('y', -10)
      .text(title);
};


let newData = new Array();
d3.json("data.json").then((data) => {
  let i = 0;
  //Pour chaque données du json
  for(let i = 0;i<data.length; i++){
    console.log("0");
    //On récupère le genre de la donnée
    let genre1 = data[i].genre
    //On récupère la date de la donnée
    let year1 = new Date(data[i].dateRelease).getFullYear()
    //Si le tableau avec les nouvelles data est vide
    if (newData.length === 0){
      console.log("1 : " + genre1 + year1);
      //console.log("genre = " +genre1);
      //console.log("year = " +year1);
      //On créé un tableau qui contient la date et le nb de musique intialisé à 1
      let listDate = new Array();
      //On push le genre, l'année et le nb de musique dans newData
      listDate.push({
        "annee":year1,
        "nb_musique":1
      })
      newData.push({
        "genre":genre1,
        "annees":listDate
      })
      console.log(newData);
    }
    //Pour chaque éléments de newData
    for (let j = 0; j<newData.length ; j++){
      console.log("2 : " + genre1 + year1);
      //console.log(year1);
      //console.log("tableau : " +newData[j]);
      //console.log(newData[j].annees.includes((obj => obj.annee == year1)));
      
      //Si le tableau d'années de newData inclus l'année de la donnée
      if (newData[j].annees.includes((obj => obj.annee == year1))){
        console.log("3 : " + genre1 + year1);
        //console.log("year " + year1);      
        //On cherche l'index qui contient l'année de la donnée 
        let ind = newData[j].annees.findIndex((obj => obj.annee == year))
        //On ajoute 1 au mn de musique de newData
        newData[j].annees[ind].nb_musique = newData[j].annees[ind].nb_musique+1;
      //Si le tableau d'années de newData n'inclus pas l'année de la donnée
      }
      
      /*let ind = newData[j].annees.indexOf((obj => obj.annee == year1));
     	console.log(newData[j].annees);
      console.log("index : " + ind);
      //Si le tableau d'années de newData inclus l'année de la donnée
      if (ind > -1){
        console.log("ICIIIII");
        console.log("3bis : " + genre1 + year1);    
        
        //On ajoute 1 au nb de musique de newData
        newData[j].annees[ind].nb_musique = newData[j].annees[ind].nb_musique+1;
      //Si le tableau d'années de newData n'inclus pas l'année de la donnée
      }*/
    
    else {
        console.log("4 : " + genre1 + year1);
        // Si le genre de la donnée est égal au genre actuel de newData
        if (genre1 === newData[j].genre){
          console.log("5 : " + genre1 + year1);
        //console.log(newData);
        //console.log("1");
        //On créé un tableau qui contient la date et le nb de musique intialisé à 1
        let listDate1 = new Array();
        listDate1.push({
          "annee":year1,
          "nb_musique":1
      	})
        //On ajoute la date à la liste des dates de newData
        newData[j].annees.push(listDate1);
        //console.log(newData);
        // Si le genre de la donnée n'est pas égal au genre actuel de newData
        } else {
          console.log("6 : " + genre1 + year1);
          //Si c'est le dernier élément des données
          if (j === newData.length-1){
            console.log("7 : " + genre1 + year1);
            //console.log("2");
            //On créé un tableau qui contient la date et le nb de musique intialisé à 1
            let listDate1 = new Array();
            listDate1.push({
              "annee":year1,
              "nb_musique":1
            })
             //On push le genre, l'année et le nb de musique dans newData
            newData.push({
              "genre":genre1,
              "annees":listDate1
            })
          }
        }
      }
    }  
  }
    //Trier les dates par ordre croissant 
  	newData.sort(function (a, b) {
            return d3['ascending'](
              +a.date,
              +b.date
            );
    })
  c